<?php
/**
 * Aliases for special pages
 *
 * @file
 * @ingroup Extensions
 * @ingroup SMWLanguage
 */
// @codingStandardsIgnoreFile

$specialPageAliases = [];

/** English (English) */
$specialPageAliases['en'] = [
	'Ask' => [ 'Ask' ],
	'Browse' => [ 'Browse' ],
	'ExportRDF' => [ 'ExportRDF' ],
	'PageProperty' => [ 'PageProperty' ],
	'Properties' => [ 'Properties' ],
	'Concepts' => [ 'Concepts' ],
	'SMWAdmin' => [ 'SemanticMediaWiki', 'SMWAdmin' ],
	'PendingTaskList' => [ 'PendingTaskList' ],
	'SearchByProperty' => [ 'SearchByProperty' ],
	'ProcessingErrorList' => [ 'ProcessingErrorList' ],
	'ConstraintErrorList' => [ 'ConstraintErrorList' ],
	'PropertyLabelSimilarity' => [ 'PropertyLabelSimilarity' ],
	'MissingRedirectAnnotations' => [ 'MissingRedirectAnnotations' ],
	'Types' => [ 'Types' ],
	'URIResolver' => [ 'URIResolver' ],
	'UnusedProperties' => [ 'UnusedProperties' ],
	'WantedProperties' => [ 'WantedProperties' ],
];

/** Afrikaans (Afrikaans) */
$specialPageAliases['af'] = [
	'Ask' => [ 'Vra' ],
	'Properties' => [ 'Eienskappe' ],
	'Concepts' => [ 'Konsepte' ],
	'Types' => [ 'Tipes' ],
];

/** Arabic (العربية) */
$specialPageAliases['ar'] = [
	'Ask' => [ 'سؤال' ],
	'Browse' => [ 'تصفح' ],
	'ExportRDF' => [ 'تصدير_RDF' ],
	'PageProperty' => [ 'صفحة_خصيصة' ],
	'Properties' => [ 'خصائص' ],
	'Concepts' => [ 'مفاهيم' ],
	'SMWAdmin' => [ 'إدارة_سمو', 'إدارة_ميدياويكي_دلالية' ],
	'SearchByProperty' => [ 'بحث_بالخصيصة' ],
	'Types' => [ 'أنواع' ],
	'URIResolver' => [ 'حال_URI' ],
	'UnusedProperties' => [ 'خصائص_غير_مستخدمة' ],
	'WantedProperties' => [ 'خصائص_مطلوبة' ],
];

/** Aramaic (ܐܪܡܝܐ) */
$specialPageAliases['arc'] = [
	'Ask' => [ 'ܫܐܠ' ],
	'Browse' => [ 'ܦܐܬ' ],
	'PageProperty' => [ 'ܦܐܬܐ_ܕܕܝܠܝܘ̈ܬܐ' ],
	'Properties' => [ 'ܕܝܠܝܘܬ̈ܐ' ],
	'SearchByProperty' => [ 'ܒܨܝ_ܒܝܕ_ܕܝܠܝܘ̈ܬܐ' ],
	'Types' => [ 'ܐܕ̈ܫܐ' ],
	'UnusedProperties' => [ 'ܕܝܠܝܘ̈ܬܐ_ܠܐ_ܦܠܝܚ̈ܬܐ' ],
	'WantedProperties' => [ 'ܕܝܠܝܘ̈ܬܐ_ܣܢܝܩ̈ܬܐ' ],
];

/** Egyptian Arabic (مصرى) */
$specialPageAliases['arz'] = [
	'Ask' => [ 'سؤال' ],
	'Browse' => [ 'براوز' ],
	'ExportRDF' => [ 'تصدير_RDF' ],
	'PageProperty' => [ 'خاصية_الصفحه' ],
	'Properties' => [ 'خصايص' ],
	'Concepts' => [ 'مبادئ' ],
	'SMWAdmin' => [ 'ادارى_SMW' ],
	'SearchByProperty' => [ 'دوّر_بالخاصيه' ],
	'Types' => [ 'انواع' ],
	'URIResolver' => [ 'محلل_يو_ار_اى' ],
	'UnusedProperties' => [ 'خصايص_مش_مستعمله' ],
	'WantedProperties' => [ 'خصايص_مطلوبه' ],
];

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = [
	'Ask' => [ 'সোধক' ],
	'Browse' => [ 'ব্ৰাউজ' ],
	'ExportRDF' => [ 'RDF_ৰপ্তানি' ],
	'Types' => [ 'প্ৰকাৰসমূহ' ],
];

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = [
	'Ask' => [ 'سوال_و_سوج_ئان' ],
	'Browse' => [ 'بروز' ],
	'ExportRDF' => [ 'آر_ڈی_اف_ئی_ڈن_کورتین' ],
	'PageProperty' => [ 'تاکدیمی_مالومات' ],
	'Properties' => [ 'مالومات' ],
	'Concepts' => [ 'موّزو_ئان' ],
	'SMWAdmin' => [ 'اس_ام_ڈبلیو_ئی_مدیر' ],
	'SearchByProperty' => [ 'گشتین_به_مالوماتی_اساس_ئا' ],
	'Types' => [ 'ڈوّل_ئان' ],
	'URIResolver' => [ 'یو_آر_آی_هل_کنۆک' ],
	'UnusedProperties' => [ 'ایستیپاده_نه_بوته_ئین_مالومات' ],
	'WantedProperties' => [ 'لوٹی_ته_بوته_ئین_مالومات' ],
];

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = [
	'Ask' => [ 'Takun' ],
	'Browse' => [ 'Ambahi' ],
	'Types' => [ 'Janis' ],
];

/** Breton (brezhoneg) */
$specialPageAliases['br'] = [
	'Ask' => [ 'Goulenn' ],
	'Browse' => [ 'Furchal' ],
	'ExportRDF' => [ 'EzorzhiañRDF' ],
	'PageProperty' => [ 'PerzhioùPajenn' ],
	'Properties' => [ 'Perzhioù' ],
	'Types' => [ 'Seurtoù' ],
];

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = [
	'Ask' => [ 'Upit' ],
	'Browse' => [ 'Pregledanje' ],
	'ExportRDF' => [ 'IzvozRDF' ],
	'Properties' => [ 'Svojstva' ],
];

/** Min Dong Chinese (Mìng-dĕ̤ng-ngṳ̄) */
$specialPageAliases['cdo'] = [
	'Ask' => [ '問' ],
	'Browse' => [ '瀏覽' ],
	'ExportRDF' => [ '導出RDF' ],
	'PageProperty' => [ '頁面屬性' ],
];

/** German (Deutsch) */
$specialPageAliases['de'] = [
	'Ask' => [ 'Semantische_Suche' ],
	'Browse' => [ 'Durchsuchen', 'Browsen' ],
	'ExportRDF' => [ 'RDF_exportieren', 'Exportiere_RDF' ],
	'PageProperty' => [ 'Seitenattribut' ],
	'Properties' => [ 'Attribute' ],
	'Concepts' => [ 'Konzepte' ],
	'SMWAdmin' => [ 'SemanticMediaWiki', 'SMW-Administration', 'SMW-Einrichtung' ],
	'SearchByProperty' => [ 'Suche_mittels_Attribut' ],
	'ProcessingErrorList' => [ 'Liste_der_Verarbeitungsfehler' ],
	'PropertyLabelSimilarity' => [ 'Ähnliche_Attributbezeichnungen' ],
	'MissingRedirectAnnotations' => [ 'Fehlende_Weiterleitungsannotationen' ],
	'Types' => [ 'Datentypen' ],
	'URIResolver' => [ 'URI-Auflöser' ],
	'UnusedProperties' => [ 'Verwaiste_Attribute' ],
	'WantedProperties' => [ 'Gewünschte_Attribute' ],
];

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = [
	'Ask' => [ 'Pers' ],
	'Browse' => [ 'Bıgeyré' ],
	'ExportRDF' => [ 'RDFTeberde' ],
	'PageProperty' => [ 'BeğsaPeran' ],
	'Properties' => [ 'Bexsiyeti' ],
	'Concepts' => [ 'Konsepti' ],
	'SMWAdmin' => [ 'SMWXızmetkar' ],
	'SearchByProperty' => [ 'ĞısusiyetkarCıgeyrayış' ],
	'Types' => [ 'Babeti' ],
	'URIResolver' => [ 'URIAgozne' ],
	'UnusedProperties' => [ 'ĞısusiyetéNékaréné' ],
	'WantedProperties' => [ 'ĞısusiyetéWaşténé' ],
];

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = [
	'Ask' => [ 'Semantiske pytanhje' ],
	'Browse' => [ 'Pśepytaś' ],
	'ExportRDF' => [ 'RDF eksportěrowaś' ],
	'PageProperty' => [ 'Bokowa kakosć' ],
	'Properties' => [ 'Kakosći' ],
	'SearchByProperty' => [ 'Z kakosću pytaś' ],
	'Types' => [ 'Datowe typy' ],
	'UnusedProperties' => [ 'Njewužywane kakosći' ],
	'WantedProperties' => [ 'Póžedane kakosći' ],
];

/** Divehi (ދިވެހިބަސް) */
$specialPageAliases['dv'] = [
	'Ask' => [ 'އައްސަވާ' ],
];

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = [
	'Ask' => [ 'Ερώτημα' ],
	'Browse' => [ 'Περιήγηση' ],
	'ExportRDF' => [ 'ΕξαγωγήRDF' ],
	'PageProperty' => [ 'ΙδιότηταΣελίδας' ],
	'Properties' => [ 'Ιδιότητες' ],
	'Concepts' => [ 'Έννοιες' ],
	'SMWAdmin' => [ 'ΔιαχείρισηSMW' ],
	'SearchByProperty' => [ 'ΑναζήτησηΜεΙδιότητα' ],
	'Types' => [ 'Τύποι' ],
	'URIResolver' => [ 'ΑναλυτήςURI' ],
	'UnusedProperties' => [ 'ΜηΧρησιμοποιούμενεςΙδιότητες' ],
	'WantedProperties' => [ 'ΖητούμενεςΙδιότητες' ],
];

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = [
	'Ask' => [ 'Peti' ],
	'Browse' => [ 'Foliumi' ],
	'ExportRDF' => [ 'Elporti_RDF', 'Eksporti_RDF' ],
	'PageProperty' => [ 'Ecoj_de_paĝo' ],
	'Properties' => [ 'Ecoj' ],
	'Types' => [ 'Specoj' ],
];

/** Spanish (español) */
$specialPageAliases['es'] = [
	'Properties' => [ 'Propiedades' ],
	'SearchByProperty' => [ 'BuscarPorPropiedad' ],
	'Types' => [ 'Tipos' ],
	'UnusedProperties' => [ 'PropiedadesNoUsadas' ],
	'WantedProperties' => [ 'PropiedadesRequeridas' ],
];

/** Persian (فارسی) */
$specialPageAliases['fa'] = [
	'Ask' => [ 'پرسش' ],
	'Browse' => [ 'مرور' ],
	'ExportRDF' => [ 'برونریزی_آردی‌اف' ],
	'PageProperty' => [ 'جزئیات_صفحه' ],
	'Properties' => [ 'جزئیات' ],
	'Concepts' => [ 'مفاهیم' ],
	'SMWAdmin' => [ 'مدیر_اس‌ام‌دبلیو' ],
	'SearchByProperty' => [ 'جستجو_بر_پایهٔ_جزئیات' ],
	'Types' => [ 'نوع‌ها' ],
	'URIResolver' => [ 'حل‌کننده_یو‌آر‌آی' ],
	'UnusedProperties' => [ 'جزئیات_استفاده_نشده' ],
	'WantedProperties' => [ 'جزئیات_درخواستی' ],
];

/** Finnish (suomi) */
$specialPageAliases['fi'] = [
	'Ask' => [ 'Kysy' ],
	'Browse' => [ 'Selaa' ],
	'ExportRDF' => [ 'RDF-vienti' ],
	'Properties' => [ 'Ominaisuudet' ],
	'SMWAdmin' => [ 'Semanttisen_Mediawikin_ylläpito' ],
	'Types' => [ 'Tyypit' ],
	'UnusedProperties' => [ 'Käyttämättömät_ominaisuudet' ],
	'WantedProperties' => [ 'Halutut_ominaisuudet' ],
];

/** French (français) */
$specialPageAliases['fr'] = [
	'Ask' => [ 'Requêter' ],
	'Browse' => [ 'Parcourir' ],
	'ExportRDF' => [ 'Export_RDF' ],
	'PageProperty' => [ 'Propriétés_de_la_page' ],
	'Properties' => [ 'Propriétés' ],
	'Concepts' => [ 'Concepts' ],
	'SearchByProperty' => [ 'Recherche_par_propriété' ],
	'Types' => [ 'Types' ],
	'UnusedProperties' => [ 'Propriétés_inutilisées' ],
	'WantedProperties' => [ 'Propriétés_demandées' ],
];

/** Galician (galego) */
$specialPageAliases['gl'] = [
	'Ask' => [ 'Preguntar' ],
	'Browse' => [ 'Navegar' ],
	'ExportRDF' => [ 'Exportar_RDF' ],
	'PageProperty' => [ 'Propiedades_da_páxina' ],
	'Properties' => [ 'Propiedades' ],
	'Concepts' => [ 'Conceptos' ],
	'SearchByProperty' => [ 'Procurar_por_propiedades' ],
	'Types' => [ 'Tipos' ],
	'UnusedProperties' => [ 'Propiedades_sen_uso' ],
	'WantedProperties' => [ 'Propiedades_requiridas' ],
];

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = [
	'Ask' => [ 'Semantischi_Suech' ],
	'Browse' => [ 'Duresueche' ],
	'ExportRDF' => [ 'Exportier_ADF' ],
	'PageProperty' => [ 'Syteattribut' ],
	'Properties' => [ 'Attribut' ],
	'SMWAdmin' => [ 'SMW-Yyrichtig' ],
	'SearchByProperty' => [ 'Suech_no_Attribut' ],
	'Types' => [ 'Datetype' ],
	'URIResolver' => [ 'URI-Ufflöser' ],
	'UnusedProperties' => [ 'Verwaisti_Attribut' ],
	'WantedProperties' => [ 'Gwinschti_Attribut' ],
];

/** Hebrew (עברית) */
$specialPageAliases['he'] = [
	'Ask' => [ 'שאלה' ],
	'Browse' => [ 'עיון' ],
	'ExportRDF' => [ 'ייצור_RDF' ],
	'PageProperty' => [ 'מאפיין_דף' ],
	'Properties' => [ 'מאפיינים' ],
	'Concepts' => [ 'רעיונות' ],
	'SMWAdmin' => [ 'ניהול_SMW' ],
	'SearchByProperty' => [ 'חיפוש_לפי_שאילתה' ],
	'Types' => [ 'סוגים' ],
	'URIResolver' => [ 'פותר_URI' ],
	'UnusedProperties' => [ 'מאפיינים_שאינם_בשימוש' ],
	'WantedProperties' => [ 'מאפיינים_מבוקשים' ],
];

/** Hindi (हिन्दी) */
$specialPageAliases['hi'] = [
	'Ask' => [ 'पूछो' ],
];

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = [
	'Ask' => [ 'Semantiske_pytanje' ],
	'Browse' => [ 'Přepytać' ],
	'ExportRDF' => [ 'RDF_eksportować' ],
	'PageProperty' => [ 'Kajkosć_strony' ],
	'Properties' => [ 'Kajkosće' ],
	'Concepts' => [ 'Koncepty' ],
	'SMWAdmin' => [ 'SMW-administracija' ],
	'SearchByProperty' => [ 'Pytanje_po_kajkosći' ],
	'Types' => [ 'Datowe_typy' ],
	'UnusedProperties' => [ 'Njewužiwane_kajkosće' ],
	'WantedProperties' => [ 'Falowace_kajkosće' ],
];

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = [
	'Ask' => [ 'Mande' ],
	'Browse' => [ 'Navige' ],
	'ExportRDF' => [ 'EkspòteRDF' ],
	'PageProperty' => [ 'ProprietePaj' ],
	'Properties' => [ 'Propriete' ],
	'SMWAdmin' => [ 'AdminSMW' ],
	'SearchByProperty' => [ 'ChachePaPropriete' ],
	'Types' => [ 'Tip' ],
	'UnusedProperties' => [ 'ProprietePaSèvi' ],
	'WantedProperties' => [ 'ProprieteKiMande' ],
];

/** Hungarian (magyar) */
$specialPageAliases['hu'] = [
	'Ask' => [ 'Kérdez' ],
	'Browse' => [ 'Böngészés' ],
	'Properties' => [ 'Tulajdonságok' ],
	'Types' => [ 'Típusok' ],
	'URIResolver' => [ 'URI-feloldó' ],
	'UnusedProperties' => [ 'Nem_használt_tulajdonságok' ],
	'WantedProperties' => [ 'Keresett_tulajdonságok' ],
];

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = [
	'Ask' => [ 'Consultar' ],
	'Browse' => [ 'Percurrer' ],
	'ExportRDF' => [ 'Exportar_RDF' ],
	'PageProperty' => [ 'Proprietate_de_pagina' ],
	'Properties' => [ 'Proprietates' ],
	'SMWAdmin' => [ 'Admin_SMW' ],
	'SearchByProperty' => [ 'Cercar_per_proprietate' ],
	'Types' => [ 'Typos' ],
	'URIResolver' => [ 'Resolvitor_de_URIs' ],
	'UnusedProperties' => [ 'Proprietates_non_usate' ],
	'WantedProperties' => [ 'Proprietates_dsesirate' ],
];

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = [
	'Ask' => [ 'Tanya' ],
	'Browse' => [ 'Jelajahi' ],
	'ExportRDF' => [ 'EksporRDF' ],
	'PageProperty' => [ 'PropertiHalaman' ],
	'Properties' => [ 'Properti' ],
	'SMWAdmin' => [ 'AdminSMW' ],
	'SearchByProperty' => [ 'PencarianProperti' ],
	'Types' => [ 'Tipe' ],
	'URIResolver' => [ 'PenguraiURI' ],
	'UnusedProperties' => [ 'PropertiTakDigunakan' ],
	'WantedProperties' => [ 'PropertiDiinginkan' ],
];

/** Italian (italiano) */
$specialPageAliases['it'] = [
	'Ask' => [ 'Chiedi' ],
	'Browse' => [ 'Esplora' ],
	'ExportRDF' => [ 'EsportaRDF' ],
	'PageProperty' => [ 'ProprietàPagina' ],
	'Properties' => [ 'Proprietà' ],
	'Concepts' => [ 'Concetti' ],
	'SMWAdmin' => [ 'AdminSMW' ],
	'SearchByProperty' => [ 'CercaPerProprietà' ],
	'Types' => [ 'Tipi' ],
	'URIResolver' => [ 'RisolutoreURI' ],
	'UnusedProperties' => [ 'ProprietàNonUtilizzate' ],
	'WantedProperties' => [ 'ProprietàRichieste' ],
];

/** Japanese (日本語) */
$specialPageAliases['ja'] = [
	'Ask' => [ '問い合わせ', '意味的検索' ],
	'Browse' => [ '閲覧' ],
	'ExportRDF' => [ 'RDF書き出し', 'RDFエクスポート', 'ＲＤＦエクスポート' ],
	'PageProperty' => [ 'ページプロパティ' ],
	'Properties' => [ 'プロパティ一覧' ],
	'Concepts' => [ '概念' ],
	'SMWAdmin' => [ 'SMW管理', 'ＳＭＷ管理' ],
	'SearchByProperty' => [ 'プロパティによる検索' ],
	'Types' => [ '型一覧' ],
	'URIResolver' => [ 'URIリゾルバー', 'ＵＲＩリゾルバー' ],
	'UnusedProperties' => [ '使われていないプロパティ' ],
	'WantedProperties' => [ '望まれているプロパティ' ],
];

/** Georgian (ქართული) */
$specialPageAliases['ka'] = [
	'Types' => [ 'ტიპები' ],
];

/** Khmer (ភាសាខ្មែរ) */
$specialPageAliases['km'] = [
	'Browse' => [ 'រាវរក' ],
	'Properties' => [ 'លក្ខណៈ' ],
	'Types' => [ 'ប្រភេទ' ],
];

/** Korean (한국어) */
$specialPageAliases['ko'] = [
	'Ask' => [ '묻기' ],
	'Browse' => [ '찾아보기' ],
	'ExportRDF' => [ 'RDF내보내기' ],
	'PageProperty' => [ '문서속성' ],
	'Properties' => [ '속성목록' ],
	'Concepts' => [ '개념목록' ],
	'SMWAdmin' => [ 'SMW관리자' ],
	'SearchByProperty' => [ '속성별검색', '속성별찾기' ],
	'Types' => [ '종류목록' ],
	'URIResolver' => [ 'URI해결' ],
	'UnusedProperties' => [ '안쓰는속성', '쓰이지않는속성' ],
	'WantedProperties' => [ '필요한속성' ],
];

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = [
	'Ask' => [ 'Froore' ],
	'Browse' => [ 'Bläddere' ],
	'ExportRDF' => [ 'RDF', 'RDF Äxpotteere' ],
	'PageProperty' => [ 'Eijeschaffte vun Sigge' ],
	'Properties' => [ 'Eijeschaffte' ],
	'SMWAdmin' => [ 'Semantesch MediaWiki Ennreschte' ],
	'SearchByProperty' => [ 'Noh Eijeschaffte söke' ],
	'Types' => [ 'Zoote vun Daate' ],
	'UnusedProperties' => [ 'Eijeschaffte di nit jebruch wääde' ],
	'WantedProperties' => [ 'Eijeschaffte di noch jebruch wääde' ],
];

/** Cornish (kernowek) */
$specialPageAliases['kw'] = [
	'Ask' => [ 'Govyn' ],
	'Browse' => [ 'Peuri' ],
	'ExportRDF' => [ 'EsperthiRDF' ],
	'PageProperty' => [ 'GnasFolen' ],
	'Properties' => [ 'Gnasow' ],
	'SearchByProperty' => [ 'HwilasHerwydhGnas' ],
];

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = [
	'Ask' => [ 'Froen' ],
	'Browse' => [ 'Browsen' ],
	'ExportRDF' => [ 'RDF_exportéieren' ],
	'PageProperty' => [ 'Säiten-Eegeschaften' ],
	'Properties' => [ 'Eegeschaften' ],
	'Concepts' => [ 'Konzepter' ],
	'SMWAdmin' => [ 'SMW-Administratioun' ],
	'SearchByProperty' => [ 'No_Eegeschaft_sichen' ],
	'Types' => [ 'Datentypen' ],
	'UnusedProperties' => [ 'Netbenotzt_Eegeschaften' ],
	'WantedProperties' => [ 'Gewënscht_Eegeschaften' ],
];

/** Lombard (lumbaart) */
$specialPageAliases['lmo'] = [
	'Ask' => [ 'Ciama' ],
];

/** Macedonian (македонски) */
$specialPageAliases['mk'] = [
	'Ask' => [ 'Прашај' ],
	'Browse' => [ 'Прелистај' ],
	'ExportRDF' => [ 'ИзвезиRDF' ],
	'PageProperty' => [ 'СвојстваНаСтраница' ],
	'Properties' => [ 'Својства' ],
	'Concepts' => [ 'Концепти' ],
	'SMWAdmin' => [ 'СМВАдминистратор' ],
	'SearchByProperty' => [ 'ПребарајПоСвојство' ],
	'Types' => [ 'Типови' ],
	'URIResolver' => [ 'URIРешавач' ],
	'UnusedProperties' => [ 'НекористениСвојства' ],
	'WantedProperties' => [ 'ПотребниСвојства' ],
];

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = [
	'Ask' => [ 'ചോദിക്കുക' ],
	'Browse' => [ 'ബ്രൗസ്' ],
	'Types' => [ 'തരങ്ങൾ' ],
];

/** Marathi (मराठी) */
$specialPageAliases['mr'] = [
	'Ask' => [ 'विचारा' ],
	'Browse' => [ 'न्याहाळा' ],
	'ExportRDF' => [ 'आरडीएफनिर्यात' ],
	'PageProperty' => [ 'पानवैशिष्ट्ये' ],
	'Properties' => [ 'वैशिष्ट्ये' ],
	'Concepts' => [ 'संकल्पना' ],
	'SMWAdmin' => [ 'एसएमडब्ल्यूप्रचालक' ],
	'SearchByProperty' => [ 'वैशिष्ट्येनुसारशोध' ],
	'Types' => [ 'प्रकार' ],
	'URIResolver' => [ 'यूआरायरिझॉल्व्हर' ],
	'UnusedProperties' => [ 'नवापरलेलीवैशिष्ट्ये' ],
	'WantedProperties' => [ 'हवीअसलेलीवैशिष्ट्ये' ],
];

/** Maltese (Malti) */
$specialPageAliases['mt'] = [
	'Ask' => [ 'Staqsi' ],
	'Browse' => [ 'Esplora' ],
];

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = [
	'Ask' => [ 'Spør' ],
	'Browse' => [ 'Se_gjennom' ],
	'ExportRDF' => [ 'Eksporter_RDF' ],
	'PageProperty' => [ 'Sideegenskaper' ],
	'Properties' => [ 'Egenskaper' ],
	'Concepts' => [ 'Konsepter' ],
	'SMWAdmin' => [ 'SMW-administrasjon' ],
	'SearchByProperty' => [ 'Søk_etter_egenskap' ],
	'Types' => [ 'Typer' ],
	'URIResolver' => [ 'URI-løser' ],
	'UnusedProperties' => [ 'Ubrukte_egenskaper' ],
	'WantedProperties' => [ 'Ønskede_egenskaper' ],
];

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = [
	'Ask' => [ 'Vragen' ],
	'Browse' => [ 'Bekieken' ],
	'ExportRDF' => [ 'RDF_uutvoeren' ],
	'PageProperty' => [ 'Ziedeigenschap' ],
	'Properties' => [ 'Eigenschappen' ],
	'Concepts' => [ 'Konsepten' ],
	'SMWAdmin' => [ 'SMW-beheer' ],
	'SearchByProperty' => [ 'Op_eigenschap_zeuken' ],
	'Types' => [ 'Soorten' ],
	'URIResolver' => [ 'URI-oplosser' ],
	'UnusedProperties' => [ 'Ongebruukten_eigenschappen' ],
	'WantedProperties' => [ 'Gewunste_eigenschappen' ],
];

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = [
	'Ask' => [ 'Vragen' ],
	'Browse' => [ 'Bekijken' ],
	'ExportRDF' => [ 'RDFExporteren' ],
	'PageProperty' => [ 'Paginaeigenschap' ],
	'Properties' => [ 'Eigenschappen' ],
	'Concepts' => [ 'Concepten' ],
	'SMWAdmin' => [ 'SMWBeheer' ],
	'SearchByProperty' => [ 'OpEigenschapZoeken' ],
	'Types' => [ 'Typen' ],
	'UnusedProperties' => [ 'OngebruikteEigenschappen' ],
	'WantedProperties' => [ 'GewensteEigenschappen' ],
];

/** Occitan (occitan) */
$specialPageAliases['oc'] = [
	'Browse' => [ 'Percórrer' ],
	'Properties' => [ 'Proprietats' ],
	'Types' => [ 'Tipes' ],
	'UnusedProperties' => [ 'Proprietats inutilizadas', 'ProprietatsInutilizadas' ],
	'WantedProperties' => [ 'Proprietats demandadas', 'ProprietatsDemandadas' ],
];

/** Oriya (ଓଡ଼ିଆ) */
$specialPageAliases['or'] = [
	'Ask' => [ 'ପଚାରନ୍ତୁ' ],
	'Browse' => [ 'ଖୋଜିବା' ],
	'PageProperty' => [ 'ପୃଷ୍ଠାର_ଗୁଣ' ],
	'Properties' => [ 'ଗୁଣ' ],
	'UnusedProperties' => [ 'ବ୍ୟବହାର_ହୋଇନଥିବା_ଗୁଣ' ],
	'WantedProperties' => [ 'ଦରକାରୀ_ଗୁଣ' ],
];

/** Punjabi (ਪੰਜਾਬੀ) */
$specialPageAliases['pa'] = [
	'Ask' => [ 'ਪੁੱਛੋ' ],
	'Browse' => [ 'ਫੇਰੀ_ਪਾਓ' ],
	'Types' => [ 'ਕਿਸਮਾਂ' ],
];

/** Polish (polski) */
$specialPageAliases['pl'] = [
	'Ask' => [ 'Pytanie' ],
	'Browse' => [ 'Przegląd' ],
	'ExportRDF' => [ 'EksportRDF' ],
	'PageProperty' => [ 'WłasnośćStrony' ],
	'Properties' => [ 'Własności' ],
	'Concepts' => [ 'Koncepty' ],
	'SMWAdmin' => [ 'AdminSMW' ],
	'SearchByProperty' => [ 'SzukanieWgWłasności' ],
	'Types' => [ 'Typy' ],
	'URIResolver' => [ 'ResolverURI' ],
	'UnusedProperties' => [ 'NieużywaneWłasności' ],
	'WantedProperties' => [ 'PotrzebneWłasności' ],
];

/** Pashto (پښتو) */
$specialPageAliases['ps'] = [
	'Ask' => [ 'پوښتل' ],
	'Browse' => [ 'سپړل' ],
	'PageProperty' => [ 'د مخ ځانتياوې' ],
	'Properties' => [ 'ځانتياوې' ],
	'Types' => [ 'ډولونه' ],
	'UnusedProperties' => [ 'ناکارېدلې ځانتياوې' ],
];

/** Portuguese (português) */
$specialPageAliases['pt'] = [
	'Ask' => [ 'Consultar' ],
	'Browse' => [ 'Navegar' ],
	'ExportRDF' => [ 'ExportarRDF' ],
	'PageProperty' => [ 'Propriedade_de_página' ],
	'Properties' => [ 'Propriedades' ],
	'Concepts' => [ 'Conceitos' ],
	'SearchByProperty' => [ 'Pesquisa_por_propriedade' ],
	'Types' => [ 'Tipos' ],
	'UnusedProperties' => [ 'Propriedades_não_utilizadas' ],
	'WantedProperties' => [ 'Propriedades_desejadas' ],
];

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = [
	'Ask' => [ 'Consultar' ],
	'Browse' => [ 'Navegar' ],
	'Concepts' => [ 'Conceitos' ],
	'ExportRDF' => [ 'ExportarRDF' ],
	'PageProperty' => [ 'Propriedade_de_página' ],
	'ProcessingErrorList' => [ 'Lista_de_erro_de_processamento' ],
	'Properties' => [ 'Propriedades' ],
	'PropertyLabelSimilarity' => [ 'Similaridade_de_nome_de_propriedade' ],
	'SearchByProperty' => [ 'Pesquisar_por_propriedade' ],
	'SMWAdmin' => [ 'SemanticMediaWiki', 'SMWAdmin' ],
	'Types' => [ 'Tipos' ],
	'UnusedProperties' => [ 'Propriedades_não_utilizadas' ],
	'URIResolver' => [ 'URIResolver' ],
	'WantedProperties' => [ 'Propriedades_desejadas' ],
];

/** Romanian (română) */
$specialPageAliases['ro'] = [
	'Browse' => [ 'Răsfoieşte' ],
];

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = [
	'Ask' => [ 'Chiedi' ],
	'Browse' => [ 'Esplora' ],
	'ExportRDF' => [ 'EsportaRDF' ],
	'PageProperty' => [ 'ProprietàPagina' ],
	'Properties' => [ 'Proprietà' ],
	'SMWAdmin' => [ 'AdminSMW' ],
	'SearchByProperty' => [ 'CercaPerProprietà' ],
	'Types' => [ 'Tipi' ],
	'URIResolver' => [ 'RisolutoreURI' ],
	'UnusedProperties' => [ 'ProprietàNonUtilizzate' ],
	'WantedProperties' => [ 'ProprietàRichieste' ],
];

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = [
	'Ask' => [ 'SpýtaťSa' ],
	'Browse' => [ 'Prehliadať' ],
	'PageProperty' => [ 'VlastnostiStránky' ],
	'Properties' => [ 'Vlastnosti' ],
	'SMWAdmin' => [ 'SprávcaSMW' ],
	'SearchByProperty' => [ 'HľadaniePodľaVlastností' ],
	'Types' => [ 'Typy' ],
	'URIResolver' => [ 'PrekladURI' ],
	'UnusedProperties' => [ 'NepoužívanéVlastnosti' ],
	'WantedProperties' => [ 'ŽiadanéVlastnosti' ],
];

/** Albanian (shqip) */
$specialPageAliases['sq'] = [
	'Ask' => [ 'Pyet' ],
	'Browse' => [ 'Sille' ],
];

/** Serbian (Cyrillic script) (српски (ћирилица)‎) */
$specialPageAliases['sr-ec'] = [
	'Ask' => [ 'Питај' ],
	'Browse' => [ 'Потражи' ],
	'Properties' => [ 'Својства' ],
	'Types' => [ 'Врсте' ],
	'UnusedProperties' => [ 'НекоришћенаСвојства', 'Некоришћена_својства' ],
	'WantedProperties' => [ 'ТраженаСвојства', 'Тражена_својства' ],
];

/** Swedish (svenska) */
$specialPageAliases['sv'] = [
	'Ask' => [ 'Fråga' ],
	'Browse' => [ 'Bläddra' ],
	'ExportRDF' => [ 'Exportera_RDF' ],
	'Properties' => [ 'Egenskaper' ],
	'Types' => [ 'Typer' ],
];

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = [
	'Ask' => [ 'Uliza' ],
	'Browse' => [ 'Fungua' ],
	'Types' => [ 'Aina' ],
];

/** Telugu (తెలుగు) */
$specialPageAliases['te'] = [
	'Ask' => [ 'అడుగు' ],
];

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = [
	'Ask' => [ 'Magtanong' ],
	'Browse' => [ 'Tumingin-tingin' ],
	'ExportRDF' => [ 'Iluwas_ang_RDF' ],
	'PageProperty' => [ 'Pag-aari_ng_pahina' ],
	'Properties' => [ 'Mga_pag-aari' ],
	'SMWAdmin' => [ 'Tagapangasiwa_ng_SMW' ],
	'SearchByProperty' => [ 'Maghanap_ayon_sa_pag-aari' ],
	'Types' => [ 'Mga_uri' ],
	'URIResolver' => [ 'Tagapaglutas_ng_URI' ],
	'UnusedProperties' => [ 'Mga_pag-aaring_hindi_ginagamit' ],
	'WantedProperties' => [ 'Mga_pag-aaring_ninanais' ],
];

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = [
	'Ask' => [ 'Sor' ],
	'Browse' => [ 'Gezin' ],
	'ExportRDF' => [ 'RDFAktar' ],
	'PageProperty' => [ 'SayfaÖzelliği' ],
	'Properties' => [ 'Özellikler' ],
	'SMWAdmin' => [ 'SMWHizmetlisi', 'SMWYöneticisi' ],
	'SearchByProperty' => [ 'ÖzelliğeGöreAra' ],
	'Types' => [ 'Türler', 'Tipler' ],
	'URIResolver' => [ 'URIÇözücü' ],
	'UnusedProperties' => [ 'KullanılmayanÖzellikler' ],
	'WantedProperties' => [ 'İstenenÖzellikler' ],
];

/** Ukrainian (українська) */
$specialPageAliases['uk'] = [
	'Properties' => [ 'Властивості' ],
	'Types' => [ 'Типи' ],
];

/** Urdu (اردو) */
$specialPageAliases['ur'] = [
	'Ask' => [ 'پوچھیں' ],
	'Types' => [ 'اقسام' ],
];

/** Venetian (vèneto) */
$specialPageAliases['vec'] = [
	'Browse' => [ 'Sfója' ],
	'Properties' => [ 'Proprietà' ],
	'Types' => [ 'Tipi' ],
];

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = [
	'Ask' => [ 'Hỏi' ],
	'Browse' => [ 'Duyệt' ],
	'ExportRDF' => [ 'Xuất_RDF' ],
	'PageProperty' => [ 'Thuộc_tính_trang' ],
	'Properties' => [ 'Thuộc_tính' ],
	'Concepts' => [ 'Khái_niệm' ],
	'SMWAdmin' => [ 'Quản_lý_SMW', 'Quản_lí_SMW' ],
	'SearchByProperty' => [ 'Tìm_theo_thuộc_tính' ],
	'Types' => [ 'Kiểu' ],
	'URIResolver' => [ 'Bộ_giải_URI' ],
	'UnusedProperties' => [ 'Thuộc_tính_không_dùng' ],
	'WantedProperties' => [ 'Thuộc_tính_cần_thiết' ],
];

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = [
	'Ask' => [ '询问' ],
	'Browse' => [ '浏览' ],
	'ExportRDF' => [ '导出RDF' ],
	'PageProperty' => [ '页面属性' ],
	'Properties' => [ '属性' ],
	'Concepts' => [ '概念' ],
	'SMWAdmin' => [ 'SMW管理' ],
	'SearchByProperty' => [ '按属性搜索' ],
	'Types' => [ '类型' ],
	'URIResolver' => [ 'URI分解器' ],
	'UnusedProperties' => [ '未使用属性' ],
	'WantedProperties' => [ '尚缺属性' ],
];

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = [
	'Ask' => [ '詢問' ],
	'Browse' => [ '瀏覽' ],
	'ExportRDF' => [ '匯出_RDF' ],
	'PageProperty' => [ '頁面屬性' ],
	'Properties' => [ '屬性' ],
	'Concepts' => [ '概念' ],
	'SMWAdmin' => [ 'SMW_管理員' ],
	'SearchByProperty' => [ '依屬性搜尋' ],
	'Types' => [ '型態' ],
	'URIResolver' => [ 'URI_分解器' ],
	'UnusedProperties' => [ '未使用屬性' ],
	'WantedProperties' => [ '需要的屬性' ],
];
